@@ -1046,8 +1046,7 @@ def model_param_plot(self, bayes_optim_summary, estimator_class, estimator_param
                     df=df,
                     feature="param",
                     color_map=bar_color_list[:-1],
-                    # color_map=color_map,
-                    box=(1.0, 1.15),
+                    bbox=(1.0, 1.15),
                     alpha=1.0,
                     legend_labels=df.columns[1:].values,
                     x_units=None,
